# GitHub Enterprise Integration
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/github-enterprise-integration#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/github-enterprise-integration#benefits)
  * [Scope and Limitations](https://help.sap.com/docs/leanix/ea/github-enterprise-integration#scope-and-limitations)
  * [Setting Up the Integration](https://help.sap.com/docs/leanix/ea/github-enterprise-integration#setting-up-the-integration)
  * [Updating the Agent Version](https://help.sap.com/docs/leanix/ea/github-enterprise-integration#updating-the-agent-version)
  * [Viewing Discovered Microservices](https://help.sap.com/docs/leanix/ea/github-enterprise-integration#viewing-discovered-microservices)
  * [Starting a Synchronization Run](https://help.sap.com/docs/leanix/ea/github-enterprise-integration#starting-a-synchronization-run)
  * [Deleting the Integration](https://help.sap.com/docs/leanix/ea/github-enterprise-integration#deleting-the-integration)


View all
Set up self-built software discovery using our out-of-the-box integration with GitHub Enterprise Server.
**Note**
This feature is available with the SAP LeanIX Technology Risk and Compliance product.
